import { jsx as _jsx } from "react/jsx-runtime";
import { forwardRef, useCallback, useState } from 'react';
import { continueRender, delayRender } from './delay-render.js';
const IFrameRefForwarding = ({ onLoad, onError, ...props }, ref) => {
    const [handle] = useState(() => delayRender(`Loading <IFrame> with source ${props.src}`));
    const didLoad = useCallback((e) => {
        continueRender(handle);
        onLoad === null || onLoad === void 0 ? void 0 : onLoad(e);
    }, [handle, onLoad]);
    const didGetError = useCallback((e) => {
        continueRender(handle);
        if (onError) {
            onError(e);
        }
        else {
            console.error('Error loading iframe:', e, 'Handle the event using the onError() prop to make this message disappear.');
        }
    }, [handle, onError]);
    return _jsx("iframe", { ...props, ref: ref, onError: didGetError, onLoad: didLoad });
};
export const IFrame = forwardRef(IFrameRefForwarding);
