import { jsx as _jsx } from "react/jsx-runtime";
import { forwardRef, useCallback, useImperativeHandle, useLayoutEffect, useRef, } from 'react';
import { continueRender, delayRender } from './delay-render.js';
import { useRemotionEnvironment } from './get-environment.js';
import { usePreload } from './prefetch.js';
const ImgRefForwarding = ({ onError, src, ...props }, ref) => {
    const imageRef = useRef(null);
    const environment = useRemotionEnvironment();
    useImperativeHandle(ref, () => {
        return imageRef.current;
    }, []);
    const actualSrc = usePreload(src);
    const didGetError = useCallback((e) => {
        var _a;
        if (onError) {
            onError(e);
        }
        else {
            console.error('Error loading image with src:', (_a = imageRef.current) === null || _a === void 0 ? void 0 : _a.src, e, 'Handle the event using the onError() prop to make this message disappear.');
        }
    }, [onError]);
    // If image source switches, make new handle
    if (environment === 'rendering') {
        // eslint-disable-next-line react-hooks/rules-of-hooks
        useLayoutEffect(() => {
            if (process.env.NODE_ENV === 'test') {
                return;
            }
            const newHandle = delayRender('Loading <Img> with src=' + src);
            const { current } = imageRef;
            const didLoad = () => {
                continueRender(newHandle);
            };
            if (current === null || current === void 0 ? void 0 : current.complete) {
                continueRender(newHandle);
            }
            else {
                current === null || current === void 0 ? void 0 : current.addEventListener('load', didLoad, { once: true });
            }
            // If tag gets unmounted, clear pending handles because image is not going to load
            return () => {
                current === null || current === void 0 ? void 0 : current.removeEventListener('load', didLoad);
                continueRender(newHandle);
            };
        }, [src]);
    }
    return (_jsx("img", { ...props, ref: imageRef, src: actualSrc, onError: didGetError }));
};
export const Img = forwardRef(ImgRefForwarding);
