import { jsx as _jsx } from "react/jsx-runtime";
import { useEffect, useLayoutEffect, useMemo, useRef, useState, } from 'react';
import { SharedAudioContextProvider } from './audio/shared-audio-tags.js';
import { CompositionManagerProvider } from './CompositionManager.js';
import { continueRender, delayRender } from './delay-render.js';
import { NativeLayersProvider } from './NativeLayers.js';
import { NonceContext } from './nonce.js';
import { PrefetchProvider } from './prefetch-state.js';
import { random } from './random.js';
import { SetTimelineContext, TimelineContext } from './timeline-position-state.js';
import { DurationsContextProvider } from './video/duration-state.js';
export const RemotionRoot = ({ children, numberOfAudioTags }) => {
    var _a;
    const [remotionRootId] = useState(() => String(random(null)));
    const [frame, setFrame] = useState((_a = window.remotion_initialFrame) !== null && _a !== void 0 ? _a : 0);
    const [playing, setPlaying] = useState(false);
    const imperativePlaying = useRef(false);
    const [fastRefreshes, setFastRefreshes] = useState(0);
    const [playbackRate, setPlaybackRate] = useState(1);
    const audioAndVideoTags = useRef([]);
    useLayoutEffect(() => {
        if (typeof window !== 'undefined') {
            window.remotion_setFrame = (f) => {
                const id = delayRender(`Setting the current frame to ${f}`);
                setFrame(f);
                requestAnimationFrame(() => continueRender(id));
            };
            window.remotion_isPlayer = false;
        }
    }, []);
    const timelineContextValue = useMemo(() => {
        return {
            frame,
            playing,
            imperativePlaying,
            rootId: remotionRootId,
            playbackRate,
            setPlaybackRate,
            audioAndVideoTags,
        };
    }, [frame, playbackRate, playing, remotionRootId]);
    const setTimelineContextValue = useMemo(() => {
        return {
            setFrame,
            setPlaying,
        };
    }, []);
    const nonceContext = useMemo(() => {
        let counter = 0;
        return {
            getNonce: () => counter++,
            fastRefreshes,
        };
    }, [fastRefreshes]);
    useEffect(() => {
        if (module.hot) {
            module.hot.addStatusHandler((status) => {
                if (status === 'idle') {
                    setFastRefreshes((i) => i + 1);
                }
            });
        }
    }, []);
    return (_jsx(NonceContext.Provider, { value: nonceContext, children: _jsx(TimelineContext.Provider, { value: timelineContextValue, children: _jsx(SetTimelineContext.Provider, { value: setTimelineContextValue, children: _jsx(PrefetchProvider, { children: _jsx(NativeLayersProvider, { children: _jsx(CompositionManagerProvider, { children: _jsx(DurationsContextProvider, { children: _jsx(SharedAudioContextProvider
                                // In the preview, which is mostly played on Desktop, we opt out of the autoplay policy fix as described in https://github.com/remotion-dev/remotion/pull/554, as it mostly applies to mobile.
                                , { 
                                    // In the preview, which is mostly played on Desktop, we opt out of the autoplay policy fix as described in https://github.com/remotion-dev/remotion/pull/554, as it mostly applies to mobile.
                                    numberOfAudioTags: numberOfAudioTags, children: children }) }) }) }) }) }) }) }));
};
