import { jsx as _jsx } from "react/jsx-runtime";
import { forwardRef, useCallback, useContext } from 'react';
import { useRemotionEnvironment } from '../get-environment.js';
import { Loop } from '../loop';
import { Sequence } from '../Sequence.js';
import { useVideoConfig } from '../use-video-config.js';
import { validateMediaProps } from '../validate-media-props.js';
import { validateStartFromProps } from '../validate-start-from-props.js';
import { DurationsContext } from '../video/duration-state.js';
import { AudioForDevelopment } from './AudioForDevelopment.js';
import { AudioForRendering } from './AudioForRendering.js';
import { SharedAudioContext } from './shared-audio-tags.js';
const AudioRefForwardingFunction = (props, ref) => {
    var _a;
    const audioContext = useContext(SharedAudioContext);
    const { startFrom, endAt, ...otherProps } = props;
    const { loop, ...propsOtherThanLoop } = props;
    const { fps } = useVideoConfig();
    const environment = useRemotionEnvironment();
    const { durations, setDurations } = useContext(DurationsContext);
    if (typeof props.src !== 'string') {
        throw new TypeError(`The \`<Audio>\` tag requires a string for \`src\`, but got ${JSON.stringify(props.src)} instead.`);
    }
    const onError = useCallback((e) => {
        console.log(e.currentTarget.error);
        throw new Error(`Could not play audio with src ${otherProps.src}: ${e.currentTarget.error}. See https://remotion.dev/docs/media-playback-error for help.`);
    }, [otherProps.src]);
    const onDuration = useCallback((src, durationInSeconds) => {
        setDurations({ type: 'got-duration', durationInSeconds, src });
    }, [setDurations]);
    if (loop && props.src && durations[props.src] !== undefined) {
        const duration = Math.floor(durations[props.src] * fps);
        const playbackRate = (_a = props.playbackRate) !== null && _a !== void 0 ? _a : 1;
        const actualDuration = duration / playbackRate;
        return (_jsx(Loop, { layout: "none", durationInFrames: Math.floor(actualDuration), children: _jsx(Audio, { ...propsOtherThanLoop, ref: ref }) }));
    }
    if (typeof startFrom !== 'undefined' || typeof endAt !== 'undefined') {
        validateStartFromProps(startFrom, endAt);
        const startFromFrameNo = startFrom !== null && startFrom !== void 0 ? startFrom : 0;
        const endAtFrameNo = endAt !== null && endAt !== void 0 ? endAt : Infinity;
        return (_jsx(Sequence, { layout: "none", from: 0 - startFromFrameNo, showInTimeline: false, durationInFrames: endAtFrameNo, children: _jsx(Audio, { ...otherProps, ref: ref }) }));
    }
    validateMediaProps(props, 'Audio');
    if (environment === 'rendering') {
        return (_jsx(AudioForRendering, { onDuration: onDuration, ...props, ref: ref, onError: onError }));
    }
    return (_jsx(AudioForDevelopment, { shouldPreMountAudioTags: audioContext !== null && audioContext.numberOfAudioTags > 0, ...props, ref: ref, onError: onError, onDuration: onDuration }));
};
export const Audio = forwardRef(AudioRefForwardingFunction);
