import { jsx as _jsx, jsxs as _jsxs } from "react/jsx-runtime";
/**
 * @vitest-environment jsdom
 */
import { render } from '@testing-library/react';
import React from 'react';
import { afterAll, beforeAll, beforeEach, describe, expect, test, vitest, } from 'vitest';
import { AudioForRendering } from '../audio/AudioForRendering.js';
import { CanUseRemotionHooksProvider } from '../CanUseRemotionHooks.js';
import { Internals } from '../internals.js';
import { expectToThrow } from './expect-to-throw.js';
let mockContext;
describe('Register and unregister asset', () => {
    function createMockContext() {
        const registerAsset = vitest.fn();
        const unregisterAsset = vitest.fn();
        window.remotion_audioEnabled = true;
        const MockProvider = ({ children }) => {
            return (_jsx(CanUseRemotionHooksProvider, { children: _jsx(Internals.CompositionManager.Provider, { value: 
                    // eslint-disable-next-line react/jsx-no-constructed-context-values
                    {
                        registerAsset,
                        unregisterAsset,
                    }, children: children }) }));
        };
        return {
            MockProvider,
            registerAsset,
            unregisterAsset,
        };
    }
    beforeEach(() => {
        mockContext = createMockContext();
    });
    test('register and unregister asset', () => {
        const props = {
            src: 'test',
            muted: false,
            volume: 50,
            onDuration: vitest.fn(),
        };
        const { unmount } = render(_jsx(CanUseRemotionHooksProvider, { children: _jsx(mockContext.MockProvider, { children: _jsx(AudioForRendering, { ...props }) }) }));
        expect(mockContext.registerAsset).toHaveBeenCalled();
        unmount();
        expect(mockContext.unregisterAsset).toHaveBeenCalled();
    });
    test('no src passed', () => {
        const props = {
            src: undefined,
            muted: false,
            volume: 50,
            onDuration: vitest.fn(),
        };
        expectToThrow(() => {
            render(_jsx(CanUseRemotionHooksProvider, { children: _jsx(mockContext.MockProvider, { children: _jsx(AudioForRendering, { ...props }) }) }));
        }, /No src passed/);
        expect(mockContext.registerAsset).not.toHaveBeenCalled();
        expect(mockContext.unregisterAsset).not.toHaveBeenCalled();
    });
});
let mockUseEffect;
describe('useEffect tests', () => {
    const useEffectSpy = vitest.spyOn(React, 'useEffect');
    mockUseEffect = vitest.fn();
    beforeAll(() => {
        useEffectSpy.mockImplementation(() => {
            mockUseEffect();
        });
    });
    afterAll(() => {
        useEffectSpy.mockRestore();
    });
    test.skip('has registered', () => {
        const props = {
            src: 'test',
            muted: false,
            volume: 50,
            onDuration: vitest.fn(),
        };
        render(_jsxs(CanUseRemotionHooksProvider, { children: [_jsx(AudioForRendering, { ...props }), ' '] }));
        expect(mockUseEffect).toHaveBeenCalled();
    });
});
