import { jsx as _jsx } from "react/jsx-runtime";
/**
 * @vitest-environment jsdom
 */
import { render } from '@testing-library/react';
import React, { useContext } from 'react';
import { describe, expect, test } from 'vitest';
import { CanUseRemotionHooksProvider } from '../CanUseRemotionHooks.js';
import { CompositionManager } from '../CompositionManager.js';
import { Loop } from '../loop';
import { RemotionRoot } from '../RemotionRoot.js';
import { expectToThrow } from './expect-to-throw.js';
const Wrapper = ({ children }) => {
    const compositions = useContext(CompositionManager);
    return (_jsx(CanUseRemotionHooksProvider, { children: _jsx(RemotionRoot, { numberOfAudioTags: 0, children: _jsx(CompositionManager.Provider
            // eslint-disable-next-line react/jsx-no-constructed-context-values
            , { 
                // eslint-disable-next-line react/jsx-no-constructed-context-values
                value: {
                    ...compositions,
                    compositions: [
                        {
                            height: 1080,
                            width: 1080,
                            fps: 30,
                            durationInFrames: 30,
                            id: 'markup',
                            nonce: 0,
                            component: React.lazy(() => Promise.resolve({
                                default: (() => null),
                            })),
                            defaultProps: undefined,
                            folderName: null,
                            parentFolderName: null,
                        },
                    ],
                    currentComposition: 'markup',
                }, children: children }) }) }));
};
describe('Loop-validation render should throw with invalid props', () => {
    describe('Throw with invalid durationInFrames prop', () => {
        test('It should throw if Loop has non-number durationInFrames', () => {
            expectToThrow(() => render(_jsx(Wrapper, { children: _jsx(Loop, { durationInFrames: '1', children: "hi" }) })), /The "durationInFrames" prop of the <Loop \/> component must be a number, but you passed a value of type string/);
        });
        test('It should throw if Loop has non-integer durationInFrames', () => {
            expectToThrow(() => render(_jsx(Wrapper, { children: _jsx(Loop, { durationInFrames: 1.1, children: "hi" }) })), /The "durationInFrames" prop of the <Loop \/> component must be an integer, but got 1.1./);
        });
        test('It should throw if Loop has a negative duration', () => {
            expectToThrow(() => render(_jsx(Wrapper, { children: _jsx(Loop, { durationInFrames: -1, children: "hi" }) })), /The "durationInFrames" prop of the <Loop \/> component must be positive, but got -1./);
        });
    });
    describe('Throw with invalid times prop', () => {
        test('It should throw if Loop has non-number times', () => {
            expectToThrow(() => render(_jsx(Wrapper, { children: _jsx(Loop, { durationInFrames: 50, times: "1", children: "hi" }) })), /You passed to "times" an argument of type string, but it must be a number./);
        });
        test('It should throw if Loop has non-integer times', () => {
            expectToThrow(() => render(_jsx(Wrapper, { children: _jsx(Loop, { durationInFrames: 50, times: 1.1, children: "hi" }) })), /The "times" prop of a loop must be an integer, but got 1.1./);
        });
    });
});
describe('Should NOT throw with valid props', () => {
    test('It should allow null as children', () => {
        expect(() => render(_jsx(Wrapper, { children: _jsx(Loop, { durationInFrames: 50, children: null }) }))).not.toThrow();
    });
    test('It should allow undefined as children', () => {
        expect(() => render(_jsx(Wrapper, { children: _jsx(Loop, { durationInFrames: 50, children: undefined }) }))).not.toThrow();
    });
});
