import { jsx as _jsx } from "react/jsx-runtime";
/**
 * @vitest-environment jsdom
 */
/* eslint-disable react/jsx-no-constructed-context-values */
import { render } from '@testing-library/react';
import { expect, test } from 'vitest';
import { CanUseRemotionHooksProvider } from '../CanUseRemotionHooks.js';
import { Sequence } from '../Sequence.js';
import { TimelineContext } from '../timeline-position-state.js';
import { useCurrentFrame } from '../use-current-frame.js';
import { WrapSequenceContext } from './wrap-sequence-context.js';
test('It should calculate the correct offset in nested sequences', () => {
    const NestedChild = () => {
        const frame = useCurrentFrame();
        return _jsx("div", { children: 'frame' + frame });
    };
    const Child = () => {
        return (_jsx(Sequence, { from: 10, durationInFrames: 50, children: _jsx(Child2, {}) }));
    };
    const Child2 = () => {
        return (_jsx(Sequence, { from: 1, durationInFrames: 50, children: _jsx(NestedChild, {}) }));
    };
    const { queryByText } = render(_jsx(WrapSequenceContext, { children: _jsx(TimelineContext.Provider, { value: {
                rootId: 'hi',
                frame: 40,
                playing: false,
                imperativePlaying: {
                    current: false,
                },
                playbackRate: 1,
                setPlaybackRate: () => {
                    throw new Error('playback rate');
                },
                audioAndVideoTags: {
                    current: [],
                },
            }, children: _jsx(Sequence, { from: 20, durationInFrames: 100, children: _jsx(Child, {}) }) }) }));
    expect(queryByText(/^frame9$/i)).not.toBe(null);
});
test('Negative offset test', () => {
    const NestedChild = () => {
        const frame = useCurrentFrame();
        return _jsx("div", { children: 'frame' + frame });
    };
    const { queryByText } = render(_jsx(WrapSequenceContext, { children: _jsx(TimelineContext.Provider, { value: {
                frame: 40,
                playing: false,
                rootId: 'hi',
                imperativePlaying: {
                    current: false,
                },
                playbackRate: 1,
                setPlaybackRate: () => {
                    throw new Error('playback rate');
                },
                audioAndVideoTags: {
                    current: [],
                },
            }, children: _jsx(Sequence, { from: -200, durationInFrames: 300, children: _jsx(Sequence, { from: 10, durationInFrames: 300, children: _jsx(Sequence, { from: 10, durationInFrames: 300, children: _jsx(NestedChild, {}) }) }) }) }) }));
    const result = queryByText(/^frame220/i);
    expect(result).not.toBe(null);
});
test('Nested negative offset test', () => {
    const NestedChild = () => {
        const frame = useCurrentFrame();
        return _jsx("div", { children: 'frame' + frame });
    };
    const startFrom = 40;
    const endAt = 90;
    const content = (_jsx(WrapSequenceContext, { children: _jsx(Sequence, { from: 0 - startFrom, durationInFrames: endAt, children: _jsx(NestedChild, {}) }) }));
    const getForFrame = (frame) => {
        const { queryByText } = render(_jsx(WrapSequenceContext, { children: _jsx(TimelineContext.Provider, { value: {
                    frame,
                    playing: false,
                    rootId: 'hi',
                    imperativePlaying: {
                        current: false,
                    },
                    playbackRate: 1,
                    setPlaybackRate: () => {
                        throw new Error('playback rate');
                    },
                    audioAndVideoTags: {
                        current: [],
                    },
                }, children: content }) }));
        return queryByText;
    };
    const frame0 = getForFrame(0);
    expect(frame0(/^frame40$/i)).not.toBe(null);
    const frame39 = getForFrame(39);
    expect(frame39(/^frame79$/i)).not.toBe(null);
    const frame50 = getForFrame(50);
    expect(frame50(/^frame90$/i)).toBe(null);
});
test.skip('Negative offset edge case', () => {
    const NestedChild = () => {
        const frame = useCurrentFrame();
        return _jsx("div", { children: 'frame' + frame });
    };
    const startFrom = 40;
    const endAt = 90;
    const content = (_jsx(WrapSequenceContext, { children: _jsx(Sequence, { from: 40, children: _jsx(Sequence, { from: 0 - startFrom, durationInFrames: endAt, children: _jsx(NestedChild, {}) }) }) }));
    const getForFrame = (frame) => {
        const { queryByText } = render(_jsx(CanUseRemotionHooksProvider, { children: _jsx(TimelineContext.Provider, { value: {
                    frame,
                    playing: false,
                    rootId: 'hi',
                    imperativePlaying: {
                        current: false,
                    },
                    playbackRate: 1,
                    setPlaybackRate: () => {
                        throw new Error('playback rate');
                    },
                    audioAndVideoTags: {
                        current: [],
                    },
                }, children: content }) }));
        return queryByText;
    };
    expect(getForFrame(0)(/^frame0/i)).toBe(null);
    expect(getForFrame(10)(/^frame10/i)).toBe(null);
    expect(getForFrame(40)(/^frame40$/i)).not.toBe(null);
    const atFrame80 = getForFrame(80)(/^frame80$/i);
    expect(atFrame80).not.toBe(null);
    const atFrame90 = getForFrame(90)(/^frame90$/i);
    expect(atFrame90).toBe(null);
});
