import { jsx as _jsx } from "react/jsx-runtime";
import { afterAll, beforeAll, expect, test, vitest } from 'vitest';
import { Internals } from '../internals.js';
import { useMediaInTimeline } from '../use-media-in-timeline.js';
import * as useVideoConfigModule from '../use-video-config.js';
import { renderHook } from './render-hook.js';
import { mockCompositionContext } from './wrap-sequence-context.js';
beforeAll(() => {
    vitest
        .spyOn(useVideoConfigModule, 'useVideoConfig')
        .mockImplementation(() => ({
        width: 10,
        height: 10,
        fps: 30,
        durationInFrames: 100,
        id: 'hithere',
        defaultProps: () => ({}),
    }));
});
afterAll(() => {
    vitest.spyOn(useVideoConfigModule, 'useVideoConfig').mockClear();
});
test('useMediaInTimeline registers and unregisters new sequence', () => {
    const registerSequence = vitest.fn();
    const unregisterSequence = vitest.fn();
    const wrapper = ({ children }) => (_jsx(Internals.CompositionManager.Provider, { value: 
        // eslint-disable-next-line react/jsx-no-constructed-context-values
        {
            ...mockCompositionContext,
            registerSequence,
            unregisterSequence,
        }, children: children }));
    const audioRef = {
        current: { volume: 0.5 },
    };
    const { unmount } = renderHook(() => useMediaInTimeline({
        volume: 1,
        src: 'test',
        mediaVolume: 1,
        mediaType: 'audio',
        mediaRef: audioRef,
        playbackRate: 1,
    }), {
        wrapper,
    });
    expect(registerSequence).toHaveBeenCalled();
    unmount();
    expect(unregisterSequence).toHaveBeenCalled();
});
