import { jsx as _jsx } from "react/jsx-runtime";
/**
 * @vitest-environment jsdom
 */
import { render } from '@testing-library/react';
import React, { useContext } from 'react';
import { describe, expect, test } from 'vitest';
import { CanUseRemotionHooksProvider } from '../CanUseRemotionHooks.js';
import { Internals } from '../internals.js';
import { Video } from '../video';
import { expectToThrow } from './expect-to-throw.js';
const Wrapper = ({ children }) => {
    const compositions = useContext(Internals.CompositionManager);
    return (_jsx(CanUseRemotionHooksProvider, { children: _jsx(Internals.RemotionRoot, { numberOfAudioTags: 0, children: _jsx(Internals.CompositionManager.Provider
            // eslint-disable-next-line react/jsx-no-constructed-context-values
            , { 
                // eslint-disable-next-line react/jsx-no-constructed-context-values
                value: {
                    ...compositions,
                    compositions: [
                        {
                            height: 1080,
                            width: 1080,
                            fps: 30,
                            durationInFrames: 30,
                            id: 'markup',
                            nonce: 0,
                            component: React.lazy(() => Promise.resolve({
                                default: (() => null),
                            })),
                            defaultProps: undefined,
                            folderName: null,
                            parentFolderName: null,
                        },
                    ],
                    currentComposition: 'markup',
                }, children: children }) }) }));
};
describe('Render correctly with props', () => {
    test('It should render Video without startFrom / endAt props', () => {
        expect(() => render(_jsx(Wrapper, { children: _jsx(Video, { src: "test" }) }))).not.toThrow();
    });
    test('It should render Video with startFrom props', () => {
        expect(() => render(_jsx(Wrapper, { children: _jsx(Video, { src: "test", startFrom: 10 }) }))).not.toThrow();
    });
    test('It should render Video with endAt props', () => {
        expect(() => render(_jsx(Wrapper, { children: _jsx(Video, { src: "test", endAt: 10 }) }))).not.toThrow();
    });
    test('It should render Video with startFrom and endAt props', () => {
        expect(() => render(_jsx(Wrapper, { children: _jsx(Video, { src: "test", startFrom: 10, endAt: 15 }) }))).not.toThrow();
    });
    test('It should throw if videoConfig/Wrapper is missing', () => {
        expectToThrow(() => render(_jsx(CanUseRemotionHooksProvider, { children: _jsx(Video, { startFrom: 10, endAt: 15 }) })), /No video config found/);
    });
});
