import { createContext, useContext, useMemo } from 'react';
export const TimelineContext = createContext({
    frame: 0,
    playing: false,
    playbackRate: 1,
    rootId: '',
    imperativePlaying: {
        current: false,
    },
    setPlaybackRate: () => {
        throw new Error('default');
    },
    audioAndVideoTags: { current: [] },
});
export const SetTimelineContext = createContext({
    setFrame: () => {
        throw new Error('default');
    },
    setPlaying: () => {
        throw new Error('default');
    },
});
export const useTimelinePosition = () => {
    const state = useContext(TimelineContext);
    return state.frame;
};
export const useTimelineSetFrame = () => {
    const { setFrame } = useContext(SetTimelineContext);
    return setFrame;
};
export const usePlayingState = () => {
    const { playing, imperativePlaying } = useContext(TimelineContext);
    const { setPlaying } = useContext(SetTimelineContext);
    return useMemo(() => [playing, setPlaying, imperativePlaying], [imperativePlaying, playing, setPlaying]);
};
