import { jsx as _jsx } from "react/jsx-runtime";
import { useCallback } from 'react';
import { useRemotionEnvironment } from '../get-environment.js';
import { Sequence } from '../Sequence.js';
import { validateMediaProps } from '../validate-media-props.js';
import { validateStartFromProps } from '../validate-start-from-props.js';
import { validateOffthreadVideoImageFormat } from '../validation/validate-offthreadvideo-image-format.js';
import { OffthreadVideoForRendering } from './OffthreadVideoForRendering.js';
import { VideoForDevelopment } from './VideoForDevelopment.js';
export const OffthreadVideo = (props) => {
    const { startFrom, endAt, ...otherProps } = props;
    const environment = useRemotionEnvironment();
    const onDuration = useCallback(() => undefined, []);
    if (typeof props.src !== 'string') {
        throw new TypeError(`The \`<OffthreadVideo>\` tag requires a string for \`src\`, but got ${JSON.stringify(props.src)} instead.`);
    }
    if (typeof startFrom !== 'undefined' || typeof endAt !== 'undefined') {
        validateStartFromProps(startFrom, endAt);
        const startFromFrameNo = startFrom !== null && startFrom !== void 0 ? startFrom : 0;
        const endAtFrameNo = endAt !== null && endAt !== void 0 ? endAt : Infinity;
        return (_jsx(Sequence, { layout: "none", from: 0 - startFromFrameNo, showInTimeline: false, durationInFrames: endAtFrameNo, children: _jsx(OffthreadVideo, { ...otherProps }) }));
    }
    validateMediaProps(props, 'Video');
    validateOffthreadVideoImageFormat(props.imageFormat);
    if (environment === 'rendering') {
        return _jsx(OffthreadVideoForRendering, { ...otherProps });
    }
    return (_jsx(VideoForDevelopment, { onDuration: onDuration, onlyWarnForMediaSeekingError: true, ...otherProps }));
};
