import { jsx as _jsx } from "react/jsx-runtime";
import { useCallback, useContext, useEffect, useMemo } from 'react';
import { getAbsoluteSrc } from '../absolute-src.js';
import { useFrameForVolumeProp, useMediaStartsAt, } from '../audio/use-audio-frame.js';
import { CompositionManager } from '../CompositionManager.js';
import { OFFTHREAD_VIDEO_CLASS_NAME } from '../default-css.js';
import { Img } from '../Img.js';
import { Internals } from '../internals.js';
import { random } from '../random.js';
import { SequenceContext } from '../Sequence.js';
import { useTimelinePosition } from '../timeline-position-state.js';
import { useCurrentFrame } from '../use-current-frame.js';
import { useUnsafeVideoConfig } from '../use-unsafe-video-config.js';
import { evaluateVolume } from '../volume-prop.js';
import { getExpectedMediaFrameUncorrected } from './get-current-time.js';
const DEFAULT_IMAGE_FORMAT = 'jpeg';
export const OffthreadVideoForRendering = ({ onError, volume: volumeProp, playbackRate, src, muted, imageFormat, allowAmplificationDuringRender, ...props }) => {
    const absoluteFrame = useTimelinePosition();
    const frame = useCurrentFrame();
    const volumePropsFrame = useFrameForVolumeProp();
    const videoConfig = useUnsafeVideoConfig();
    const sequenceContext = useContext(SequenceContext);
    const mediaStartsAt = useMediaStartsAt();
    const { registerAsset, unregisterAsset } = useContext(CompositionManager);
    if (!src) {
        throw new TypeError('No `src` was passed to <OffthreadVideo>.');
    }
    // Generate a string that's as unique as possible for this asset
    // but at the same time the same on all threads
    const id = useMemo(() => `offthreadvideo-${random(src !== null && src !== void 0 ? src : '')}-${sequenceContext === null || sequenceContext === void 0 ? void 0 : sequenceContext.cumulatedFrom}-${sequenceContext === null || sequenceContext === void 0 ? void 0 : sequenceContext.relativeFrom}-${sequenceContext === null || sequenceContext === void 0 ? void 0 : sequenceContext.durationInFrames}`, [
        src,
        sequenceContext === null || sequenceContext === void 0 ? void 0 : sequenceContext.cumulatedFrom,
        sequenceContext === null || sequenceContext === void 0 ? void 0 : sequenceContext.relativeFrom,
        sequenceContext === null || sequenceContext === void 0 ? void 0 : sequenceContext.durationInFrames,
    ]);
    if (!videoConfig) {
        throw new Error('No video config found');
    }
    const volume = evaluateVolume({
        volume: volumeProp,
        frame: volumePropsFrame,
        mediaVolume: 1,
        allowAmplificationDuringRender: allowAmplificationDuringRender !== null && allowAmplificationDuringRender !== void 0 ? allowAmplificationDuringRender : false,
    });
    useEffect(() => {
        if (!src) {
            throw new Error('No src passed');
        }
        if (!window.remotion_videoEnabled) {
            return;
        }
        if (muted) {
            return;
        }
        if (volume <= 0) {
            return;
        }
        registerAsset({
            type: 'video',
            src: getAbsoluteSrc(src),
            id,
            frame: absoluteFrame,
            volume,
            mediaFrame: frame,
            playbackRate: playbackRate !== null && playbackRate !== void 0 ? playbackRate : 1,
            allowAmplificationDuringRender: allowAmplificationDuringRender !== null && allowAmplificationDuringRender !== void 0 ? allowAmplificationDuringRender : false,
        });
        return () => unregisterAsset(id);
    }, [
        muted,
        src,
        registerAsset,
        id,
        unregisterAsset,
        volume,
        frame,
        absoluteFrame,
        playbackRate,
        allowAmplificationDuringRender,
    ]);
    const currentTime = useMemo(() => {
        return (getExpectedMediaFrameUncorrected({
            frame,
            playbackRate: playbackRate || 1,
            startFrom: -mediaStartsAt,
        }) / videoConfig.fps);
    }, [frame, mediaStartsAt, playbackRate, videoConfig.fps]);
    const actualSrc = useMemo(() => {
        return `http://localhost:${window.remotion_proxyPort}/proxy?src=${encodeURIComponent(getAbsoluteSrc(src))}&time=${encodeURIComponent(currentTime)}&imageFormat=${imageFormat !== null && imageFormat !== void 0 ? imageFormat : DEFAULT_IMAGE_FORMAT}`;
    }, [currentTime, imageFormat, src]);
    const onErr = useCallback((e) => {
        onError === null || onError === void 0 ? void 0 : onError(e);
    }, [onError]);
    const className = useMemo(() => {
        return [OFFTHREAD_VIDEO_CLASS_NAME, props.className]
            .filter(Internals.truthy)
            .join(' ');
    }, [props.className]);
    return (_jsx(Img, { src: actualSrc, className: className, ...props, onError: onErr }));
};
