import { jsx as _jsx } from "react/jsx-runtime";
import { forwardRef, useCallback, useContext } from 'react';
import { useRemotionEnvironment } from '../get-environment.js';
import { Loop } from '../loop';
import { Sequence } from '../Sequence.js';
import { useVideoConfig } from '../use-video-config.js';
import { validateMediaProps } from '../validate-media-props.js';
import { validateStartFromProps } from '../validate-start-from-props.js';
import { DurationsContext } from './duration-state.js';
import { VideoForDevelopment } from './VideoForDevelopment.js';
import { VideoForRendering } from './VideoForRendering.js';
const VideoForwardingFunction = (props, ref) => {
    var _a;
    const { startFrom, endAt, ...otherProps } = props;
    const { loop, ...propsOtherThanLoop } = props;
    const { fps } = useVideoConfig();
    const environment = useRemotionEnvironment();
    const { durations, setDurations } = useContext(DurationsContext);
    if (typeof ref === 'string') {
        throw new Error('string refs are not supported');
    }
    if (typeof props.src !== 'string') {
        throw new TypeError(`The \`<Video>\` tag requires a string for \`src\`, but got ${JSON.stringify(props.src)} instead.`);
    }
    const onDuration = useCallback((src, durationInSeconds) => {
        setDurations({ type: 'got-duration', durationInSeconds, src });
    }, [setDurations]);
    if (loop && props.src && durations[props.src] !== undefined) {
        const naturalDuration = durations[props.src] * fps;
        const playbackRate = (_a = props.playbackRate) !== null && _a !== void 0 ? _a : 1;
        const durationInFrames = Math.floor(naturalDuration / playbackRate);
        return (_jsx(Loop, { durationInFrames: durationInFrames, children: _jsx(Video, { ...propsOtherThanLoop, ref: ref }) }));
    }
    if (typeof startFrom !== 'undefined' || typeof endAt !== 'undefined') {
        validateStartFromProps(startFrom, endAt);
        const startFromFrameNo = startFrom !== null && startFrom !== void 0 ? startFrom : 0;
        const endAtFrameNo = endAt !== null && endAt !== void 0 ? endAt : Infinity;
        return (_jsx(Sequence, { layout: "none", from: 0 - startFromFrameNo, showInTimeline: false, durationInFrames: endAtFrameNo, children: _jsx(Video, { ...otherProps, ref: ref }) }));
    }
    validateMediaProps(props, 'Video');
    if (environment === 'rendering') {
        return (_jsx(VideoForRendering, { onDuration: onDuration, ...otherProps, ref: ref }));
    }
    return (_jsx(VideoForDevelopment, { onlyWarnForMediaSeekingError: false, ...otherProps, ref: ref, onDuration: onDuration }));
};
const forward = forwardRef;
export const Video = forward(VideoForwardingFunction);
