import { jsx as _jsx } from "react/jsx-runtime";
// This is used for when other reconcilers are being used
// such as in React Three Fiber. All the contexts need to be passed again
// for them to be useable
import React, { useMemo } from 'react';
import { CanUseRemotionHooks } from './CanUseRemotionHooks.js';
import { CompositionManager } from './CompositionManager.js';
import { NativeLayersContext } from './NativeLayers.js';
import { NonceContext } from './nonce.js';
import { PreloadContext } from './prefetch-state.js';
import { SequenceContext } from './Sequence.js';
import { SetTimelineContext, TimelineContext } from './timeline-position-state.js';
export function useRemotionContexts() {
    const compositionManagerCtx = React.useContext(CompositionManager);
    const timelineContext = React.useContext(TimelineContext);
    const setTimelineContext = React.useContext(SetTimelineContext);
    const sequenceContext = React.useContext(SequenceContext);
    const nonceContext = React.useContext(NonceContext);
    const canUseRemotionHooksContext = React.useContext(CanUseRemotionHooks);
    const nativeLayersContext = React.useContext(NativeLayersContext);
    const preloadContext = React.useContext(PreloadContext);
    return useMemo(() => ({
        compositionManagerCtx,
        timelineContext,
        setTimelineContext,
        sequenceContext,
        nonceContext,
        canUseRemotionHooksContext,
        nativeLayersContext,
        preloadContext,
    }), [
        compositionManagerCtx,
        nonceContext,
        sequenceContext,
        setTimelineContext,
        timelineContext,
        canUseRemotionHooksContext,
        nativeLayersContext,
        preloadContext,
    ]);
}
export const RemotionContextProvider = (props) => {
    const { children, contexts } = props;
    return (_jsx(CanUseRemotionHooks.Provider, { value: contexts.canUseRemotionHooksContext, children: _jsx(NonceContext.Provider, { value: contexts.nonceContext, children: _jsx(NativeLayersContext.Provider, { value: contexts.nativeLayersContext, children: _jsx(PreloadContext.Provider, { value: contexts.preloadContext, children: _jsx(CompositionManager.Provider, { value: contexts.compositionManagerCtx, children: _jsx(TimelineContext.Provider, { value: contexts.timelineContext, children: _jsx(SetTimelineContext.Provider, { value: contexts.setTimelineContext, children: _jsx(SequenceContext.Provider, { value: contexts.sequenceContext, children: children }) }) }) }) }) }) }) }));
};
